@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::GitHubREADME::Badge;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Moose;
 use namespace::autoclean;
@@ -15,7 +15,7 @@ with 'Dist::Zilla::Role::AfterBuild';
 has badges => (
     is      => 'rw',
     isa     => 'ArrayRef[Str]',
-    default => sub { ['travis', 'coveralls'] },
+    default => sub { ['travis', 'coveralls', 'cpants'] },
 );
 sub mvp_multivalue_args { ('badges') }
 
@@ -49,7 +49,9 @@ sub after_build {
         } elsif ($badge eq 'gitter') {
             push @badges, "[![Gitter chat](https://badges.gitter.im/$user_name/$repository_name.png)](https://gitter.im/$user_name/$repository_name)";
         } elsif ($badge eq 'cpants') {
-            push @badges, "![](http://cpants.cpanauthors.org/dist/$distname.png)";
+            push @badges, "![Kwalitee status](http://cpants.cpanauthors.org/dist/$distname.png)";
+        } elsif ($badge eq 'issues') {
+            push @badges, "[![GitHub issues](https://img.shields.io/github/issues/$user_name/$repository_name.svg)](https://github.com/$user_name/$repository_name/issues)";
         }
     }
 
